package com.ycwl.basic.service.impl.pc;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ycwl.basic.mapper.pc.ScenicMapper;
import com.ycwl.basic.model.pc.scenic.entity.ScenicConfigEntity;
import com.ycwl.basic.model.pc.scenic.req.ScenicAddOrUpdateReq;
import com.ycwl.basic.model.pc.scenic.req.ScenicReqQuery;
import com.ycwl.basic.model.pc.scenic.resp.ScenicRespVO;
import com.ycwl.basic.service.pc.ScenicService;
import com.ycwl.basic.utils.ApiResponse;
import com.ycwl.basic.utils.SnowFlakeUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/3 15:25
 */
@Service
public class ScenicServiceImpl implements ScenicService {
    @Autowired
    private ScenicMapper scenicMapper;

    @Override
    public ApiResponse<PageInfo<ScenicRespVO>> pageQuery(ScenicReqQuery scenicReqQuery) {
        PageHelper.startPage(scenicReqQuery.getPageNum(), scenicReqQuery.getPageSize());
        List<ScenicRespVO> list = scenicMapper.list(scenicReqQuery);
        PageInfo<ScenicRespVO> pageInfo = new PageInfo<>(list);
        return ApiResponse.success(pageInfo);
    }

    @Override
    public ApiResponse<List<ScenicRespVO>> list(ScenicReqQuery scenicReqQuery) {
        return ApiResponse.success(scenicMapper.list(scenicReqQuery));
    }

    @Override
    public ApiResponse<ScenicRespVO> getById(Long id) {
        return ApiResponse.success(scenicMapper.getById(id));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ApiResponse<Boolean> add(ScenicAddOrUpdateReq scenicAddReq) {
        Long scenicId = SnowFlakeUtil.getLongId();
        scenicAddReq.setId(scenicId);
        int add = scenicMapper.add(scenicAddReq);
        if (add > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区添加失败");
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ApiResponse<Boolean> deleteById(Long id) {
        int i = scenicMapper.deleteById(id);
        if (i > 0) {
            scenicMapper.deleteConfigByscenicId(id);
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区删除失败");
        }
    }

    @Override
    public ApiResponse<Boolean> update(ScenicAddOrUpdateReq scenicUpdateReq) {
        int i = scenicMapper.update(scenicUpdateReq);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区修改失败");
        }
    }

    @Override
    public ApiResponse<Boolean> updateStatus(Long id) {
        int i = scenicMapper.updateStatus(id);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区状态修改失败");
        }
    }

    @Override
    public ApiResponse<Boolean> addConfig(ScenicConfigEntity scenicConfig) {
        int i = scenicMapper.addConfig(scenicConfig);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区配置添加失败");
        }
    }

    @Override
    public ApiResponse<Boolean> updateConfigById(ScenicConfigEntity scenicConfig) {
        int i = scenicMapper.updateConfigById(scenicConfig);
        if (i > 0) {
            return ApiResponse.success(true);
        }else {
            return ApiResponse.fail("景区配置修改失败");
        }
    }
}
